@@ -599,13 +599,17 @@
     };
 
     CanonicalFragmentIdentifier.prototype.scroll_to = function(cfi, callback, doc) {
-      var ec, eo, fn, ndoc, node, nwin, point, r, sc, so, span, _ref;
+      var ec, eo, fn, ndoc, node, nwin, point, r, sc, so, span, _ref, _ref1, _ref2;
       if (callback == null) {
         callback = false;
       }
       if (doc == null) {
         doc = typeof window !== "undefined" && window !== null ? window.document : void 0;
       }
+      if (((_ref = window.mathjax) != null ? _ref.math_present : void 0) && !((_ref1 = window.mathjax) != null ? _ref1.math_loaded : void 0)) {
+        window.mathjax.pending_cfi = [cfi, callback];
+        return;
+      }
       point = this.point(cfi, doc);
       if (!point) {
         log("No point found for cfi: " + cfi);
@@ -616,7 +620,7 @@
       }
       if (point.range !== null) {
         r = point.range;
-        _ref = [r.startOffset, r.endOffset, r.startContainer, r.endContainer], so = _ref[0], eo = _ref[1], sc = _ref[2], ec = _ref[3];
+        _ref2 = [r.startOffset, r.endOffset, r.startContainer, r.endContainer], so = _ref2[0], eo = _ref2[1], sc = _ref2[2], ec = _ref2[3];
         node = r.startContainer;
         ndoc = node.ownerDocument;
         nwin = ndoc.defaultView;
@@ -625,12 +629,12 @@
         r.surroundContents(span);
         span.scrollIntoView();
         fn = function() {
-          var node, p, rect, rects, x, y, _i, _len, _ref1, _ref2;
+          var node, p, rect, rects, x, y, _i, _len, _ref3, _ref4;
           rect = span.getBoundingClientRect();
           p = span.parentNode;
-          _ref1 = span.childNodes;
-          for (_i = 0, _len = _ref1.length; _i < _len; _i++) {
-            node = _ref1[_i];
+          _ref3 = span.childNodes;
+          for (_i = 0, _len = _ref3.length; _i < _len; _i++) {
+            node = _ref3[_i];
             span.removeChild(node);
             p.insertBefore(node, span);
           }
@@ -644,7 +648,7 @@
           }
           x = point.a * rect.left + (1 - point.a) * rect.right;
           y = (rect.top + rect.bottom) / 2;
-          _ref2 = viewport_to_document(x, y, ndoc), x = _ref2[0], y = _ref2[1];
+          _ref4 = viewport_to_document(x, y, ndoc), x = _ref4[0], y = _ref4[1];
           if (callback) {
             return callback(x, y);
           }
@@ -654,9 +658,9 @@
         nwin = node.ownerDocument.defaultView;
         node.scrollIntoView();
         fn = function() {
-          var x, y, _ref1;
+          var x, y, _ref3;
           r = node.getBoundingClientRect();
-          _ref1 = viewport_to_document(r.left, r.top, node.ownerDocument), x = _ref1[0], y = _ref1[1];
+          _ref3 = viewport_to_document(r.left, r.top, node.ownerDocument), x = _ref3[0], y = _ref3[1];
           if (typeof point.x === 'number' && node.offsetWidth) {
             x += (point.x * node.offsetWidth) / 100;
           }
@@ -673,8 +677,45 @@
       return null;
     };
 
+    CanonicalFragmentIdentifier.prototype.at_point = function(ox, oy) {
+      var cfi, dist, node, point, r, rect, x, y, _ref, _ref1;
+      dist = function(p1, p2) {
+        return Math.sqrt(Math.pow(p1[0] - p2[0], 2), Math.pow(p1[1] - p2[1], 2));
+      };
+      try {
+        cfi = window.cfi.at(ox, oy);
+        point = window.cfi.point(cfi);
+      } catch (err) {
+        cfi = null;
+      }
+      if (cfi) {
+        if (point.range !== null) {
+          r = point.range;
+          rect = r.getClientRects()[0];
+          x = point.a * rect.left + (1 - point.a) * rect.right;
+          y = (rect.top + rect.bottom) / 2;
+          _ref = viewport_to_document(x, y, r.startContainer.ownerDocument), x = _ref[0], y = _ref[1];
+        } else {
+          node = point.node;
+          r = node.getBoundingClientRect();
+          _ref1 = viewport_to_document(r.left, r.top, node.ownerDocument), x = _ref1[0], y = _ref1[1];
+          if (typeof point.x === 'number' && node.offsetWidth) {
+            x += (point.x * node.offsetWidth) / 100;
+          }
+          if (typeof point.y === 'number' && node.offsetHeight) {
+            y += (point.y * node.offsetHeight) / 100;
+          }
+        }
+        if (dist(viewport_to_document(ox, oy), [x, y]) > 50) {
+          cfi = null;
+        }
+      }
+      return cfi;
+    };
+
     CanonicalFragmentIdentifier.prototype.at_current = function() {
-      var cfi, cury, de, delta, deltax, deltay, direction, dist, get_cfi, max, maxx, maxy, minx, miny, px, py, rect, winh, winw, winx, winy, x, x_loop, y, _i, _len, _ref, _ref1, _ref2, _ref3;
+      var cfi, cury, de, delta, deltax, deltay, direction, max, maxx, maxy, minx, miny, px, py, rect, winh, winw, winx, winy, x, x_loop, y, _i, _len, _ref, _ref1, _ref2, _ref3,
+        _this = this;
       _ref = window_scroll_pos(), winx = _ref[0], winy = _ref[1];
       _ref1 = [window.innerWidth, window.innerHeight], winw = _ref1[0], winh = _ref1[1];
       max = Math.max;
@@ -686,41 +727,6 @@
       maxy = winh;
       minx = max(-winx, -winw);
       maxx = winw;
-      dist = function(p1, p2) {
-        return Math.sqrt(Math.pow(p1[0] - p2[0], 2), Math.pow(p1[1] - p2[1], 2));
-      };
-      get_cfi = function(ox, oy) {
-        var cfi, node, point, r, rect, x, y, _ref2, _ref3;
-        try {
-          cfi = window.cfi.at(ox, oy);
-          point = window.cfi.point(cfi);
-        } catch (err) {
-          cfi = null;
-        }
-        if (cfi) {
-          if (point.range !== null) {
-            r = point.range;
-            rect = r.getClientRects()[0];
-            x = point.a * rect.left + (1 - point.a) * rect.right;
-            y = (rect.top + rect.bottom) / 2;
-            _ref2 = viewport_to_document(x, y, r.startContainer.ownerDocument), x = _ref2[0], y = _ref2[1];
-          } else {
-            node = point.node;
-            r = node.getBoundingClientRect();
-            _ref3 = viewport_to_document(r.left, r.top, node.ownerDocument), x = _ref3[0], y = _ref3[1];
-            if (typeof point.x === 'number' && node.offsetWidth) {
-              x += (point.x * node.offsetWidth) / 100;
-            }
-            if (typeof point.y === 'number' && node.offsetHeight) {
-              y += (point.y * node.offsetHeight) / 100;
-            }
-          }
-          if (dist(viewport_to_document(ox, oy), [x, y]) > 50) {
-            cfi = null;
-          }
-        }
-        return cfi;
-      };
       x_loop = function(cury) {
         var cfi, curx, delta, direction, _i, _len, _ref2;
         _ref2 = [-1, 1];
@@ -729,7 +735,7 @@
           delta = deltax * direction;
           curx = 0;
           while (!((direction < 0 && curx < minx) || (direction > 0 && curx > maxx))) {
-            cfi = get_cfi(curx, cury);
+            cfi = _this.at_point(curx, cury);
             if (cfi) {
               return cfi;
             }
