@@ -28,6 +28,10 @@
       this.current_page_height = null;
       this.document_margins = null;
       this.use_document_margins = false;
+      this.footer_template = null;
+      this.header_template = null;
+      this.header = null;
+      this.footer = null;
     }
 
     PagedDisplay.prototype.read_document_margins = function() {
@@ -127,6 +131,7 @@
         sm += Math.ceil((col_width - this.max_col_width) / 2 * n);
         col_width = Math.max(100, ((ww - adjust) / n) - 2 * sm);
       }
+      this.col_width = col_width;
       this.page_width = col_width + 2 * sm;
       this.screen_width = this.page_width * this.cols_per_screen;
       this.current_page_height = window.innerHeight - this.margin_top - this.margin_bottom;
@@ -194,6 +199,40 @@
       return sm;
     };
 
+    PagedDisplay.prototype.create_header_footer = function() {
+      if (this.header_template !== null) {
+        this.header = document.createElement('div');
+        this.header.setAttribute('style', "overflow:hidden; display:block; position:absolute; left:" + this.side_margin + "px; top: 0px; height: " + this.margin_top + "px; width: " + this.col_width + "px; margin: 0; padding: 0");
+        document.body.appendChild(this.header);
+      }
+      if (this.footer_template !== null) {
+        this.footer = document.createElement('div');
+        this.footer.setAttribute('style', "overflow:hidden; display:block; position:absolute; left:" + this.side_margin + "px; top: " + (window.innerHeight - this.margin_bottom) + "px; height: " + this.margin_bottom + "px; width: " + this.col_width + "px; margin: 0; padding: 0");
+        document.body.appendChild(this.footer);
+      }
+      return this.update_header_footer(1);
+    };
+
+    PagedDisplay.prototype.position_header_footer = function() {
+      var left, top, _ref;
+      _ref = calibre_utils.viewport_to_document(0, 0, document.body.ownerDocument), left = _ref[0], top = _ref[1];
+      if (this.header !== null) {
+        this.header.style.setProperty('left', left + 'px');
+      }
+      if (this.footer !== null) {
+        return this.footer.style.setProperty('left', left + 'px');
+      }
+    };
+
+    PagedDisplay.prototype.update_header_footer = function(pagenum) {
+      if (this.header !== null) {
+        this.header.innerHTML = this.header_template.replace(/_PAGENUM_/g, pagenum + "");
+      }
+      if (this.footer !== null) {
+        return this.footer.innerHTML = this.footer_template.replace(/_PAGENUM_/g, pagenum + "");
+      }
+    };
+
     PagedDisplay.prototype.fit_images = function() {
       var br, col, col_width, data, doc, images, img, left, max_width, maxh, previously_limited, rleft, rright, vimages, width, _i, _j, _k, _len, _len1, _len2, _ref, _ref1, _results;
       images = [];
@@ -293,6 +332,26 @@
       return Math.floor(xpos / this.page_width);
     };
 
+    PagedDisplay.prototype.column_location = function(elem) {
+      var br, c, height, left, top, width, _ref;
+      br = elem.getBoundingClientRect();
+      _ref = calibre_utils.viewport_to_document(br.left, br.top, elem.ownerDocument), left = _ref[0], top = _ref[1];
+      c = this.column_at(left);
+      width = Math.min(br.right, (c + 1) * this.page_width) - br.left;
+      if (br.bottom < br.top) {
+        br.bottom = window.innerHeight;
+      }
+      height = Math.min(br.bottom, window.innerHeight) - br.top;
+      left -= c * this.page_width;
+      return {
+        'column': c,
+        'left': left,
+        'top': top,
+        'width': width,
+        'height': height
+      };
+    };
+
     PagedDisplay.prototype.column_boundaries = function() {
       var l;
       l = this.column_at(window.pageXOffset + 10);
