@@ -40,7 +40,7 @@ class Stage2(Command):
 class Stage3(Command):
 
    description = 'Stage 3 of the publish process'
-   sub_commands = ['upload_user_manual', 'upload_demo', 'sdist']
+   sub_commands = ['upload_user_manual', 'upload_demo', 'sdist', 'tag_release']
 
 class Stage4(Command):
 
@@ -50,7 +50,7 @@ class Stage4(Command):
 class Stage5(Command):
 
     description = 'Stage 5 of the publish process'
-    sub_commands = ['tag_release', 'upload_to_server']
+    sub_commands = ['upload_to_server']
 
     def run(self, opts):
         subprocess.check_call('rm -rf build/* dist/*', shell=True)
@@ -66,7 +66,7 @@ class Manual(Command):
 
     def run(self, opts):
         cwd = os.path.abspath(os.getcwd())
-        os.chdir(os.path.join(self.SRC, 'calibre', 'manual'))
+        os.chdir(os.path.join(self.SRC, '..', 'manual'))
         try:
             for d in ('.build', 'cli'):
                 if os.path.exists(d):
@@ -80,8 +80,21 @@ class Manual(Command):
                                    '-d', '.build/doctrees', '.', '.build/html'])
             subprocess.check_call(['sphinx-build', '-b', 'myepub', '-d',
                                    '.build/doctrees', '.', '.build/epub'])
-            shutil.copyfile(self.j('.build', 'epub', 'calibre.epub'), self.j('.build',
-                'html', 'calibre.epub'))
+            subprocess.check_call(['sphinx-build', '-b', 'mylatex', '-d',
+                                   '.build/doctrees', '.', '.build/latex'])
+            pwd = os.getcwdu()
+            os.chdir('.build/latex')
+            subprocess.check_call(['make', 'all-pdf'], stdout=open(os.devnull,
+                'wb'))
+            os.chdir(pwd)
+            epub_dest = self.j('.build', 'html', 'calibre.epub')
+            pdf_dest = self.j('.build', 'html', 'calibre.pdf')
+            shutil.copyfile(self.j('.build', 'epub', 'calibre.epub'), epub_dest)
+            shutil.copyfile(self.j('.build', 'latex', 'calibre.pdf'), pdf_dest)
+            subprocess.check_call(['ebook-convert', epub_dest,
+                epub_dest.rpartition('.')[0] + '.azw3',
+                '--page-breaks-before=/', '--disable-font-rescaling',
+                '--chapter=/'])
         finally:
             os.chdir(cwd)
 
