@@ -264,7 +264,7 @@ def extract(path, dir):
     with open(path, 'rb') as f:
         id_ = f.read(3)
     if id_ == b'Rar':
-        from calibre.libunrar import extract as rarextract
+        from calibre.utils.unrar import extract as rarextract
         extractor = rarextract
     elif id_.startswith(b'PK'):
         from calibre.libunzip import extract as zipextract
@@ -276,7 +276,7 @@ def extract(path, dir):
             from calibre.libunzip import extract as zipextract
             extractor = zipextract
         elif ext in ['cbr', 'rar']:
-            from calibre.libunrar import extract as rarextract
+            from calibre.utils.unrar import extract as rarextract
             extractor = rarextract
     if extractor is None:
         raise Exception('Unknown archive type')
@@ -329,6 +329,7 @@ def get_parsed_proxy(typ='http', debug=True):
                     ans['port'] = int(ans['port'])
             except:
                 if debug:
+                    import traceback
                     traceback.print_exc()
             else:
                 if debug:
@@ -689,29 +690,6 @@ def remove_bracketed_text(src,
             buf.append(char)
     return u''.join(buf)
 
-if isosx:
-    import glob, shutil
-    fdir = os.path.expanduser('~/.fonts')
-    try:
-        if not os.path.exists(fdir):
-            os.makedirs(fdir)
-        if not os.path.exists(os.path.join(fdir, 'LiberationSans_Regular.ttf')):
-            base = P('fonts/liberation/*.ttf')
-            for f in glob.glob(base):
-                shutil.copy2(f, fdir)
-    except:
-        import traceback
-        traceback.print_exc()
-
-def load_builtin_fonts():
-    import glob
-    from PyQt4.Qt import QFontDatabase
-    base = P('fonts/liberation/*.ttf')
-    for f in glob.glob(base):
-        QFontDatabase.addApplicationFont(f)
-    return 'Liberation Serif', 'Liberation Sans', 'Liberation Mono'
-
-
 def ipython(user_ns=None):
     from calibre.utils.ipython import ipython
     ipython(user_ns=user_ns)
