@@ -10,7 +10,7 @@ import cStringIO
 
 from calibre.devices.usbms.driver import USBMS
 
-HTC_BCDS = [0x100, 0x0222, 0x0226, 0x227, 0x228, 0x229, 0x0231, 0x9999]
+HTC_BCDS = [0x100, 0x0222, 0x0224, 0x0226, 0x227, 0x228, 0x229, 0x0231, 0x9999]
 
 class ANDROID(USBMS):
 
@@ -48,11 +48,15 @@ class ANDROID(USBMS):
                        0x2910 : HTC_BCDS,
                        0xe77  : HTC_BCDS,
                        0xff9  : HTC_BCDS,
+                       0x0001 : [0x255],
             },
 
             # Eken
             0x040d : { 0x8510 : [0x0001], 0x0851 : [0x1] },
 
+            # Trekstor
+            0x1e68 : { 0x006a : [0x0231] },
+
             # Motorola
             0x22b8 : { 0x41d9 : [0x216], 0x2d61 : [0x100], 0x2d67 : [0x100],
                        0x2de8 : [0x229],
@@ -92,6 +96,7 @@ class ANDROID(USBMS):
             # Google
             0x18d1 : {
                 0x0001 : [0x0223, 0x230, 0x9999],
+                0x0002 : [0x9999],
                 0x0003 : [0x0230, 0x9999],
                 0x4e11 : [0x0100, 0x226, 0x227],
                 0x4e12 : [0x0100, 0x226, 0x227],
@@ -140,7 +145,7 @@ class ANDROID(USBMS):
 
             # LG
             0x1004 : {
-                    0x61c5 : [0x100, 0x226, 0x227, 0x9999],
+                    0x61c5 : [0x100, 0x226, 0x227, 0x229, 0x9999],
                     0x61cc : [0x226, 0x227, 0x9999, 0x100],
                     0x61ce : [0x226, 0x227, 0x9999, 0x100],
                     0x618e : [0x226, 0x227, 0x9999, 0x100],
@@ -189,8 +194,8 @@ class ANDROID(USBMS):
             # Pantech
             0x10a9 : { 0x6050 : [0x227] },
 
-            # Prestigio
-            0x2207 : { 0 : [0x222] },
+            # Prestigio and Teclast
+            0x2207 : { 0 : [0x222], 0x10 : [0x222] },
 
             }
     EBOOK_DIR_MAIN = ['eBooks/import', 'wordplayer/calibretransfer', 'Books',
@@ -212,8 +217,9 @@ class ANDROID(USBMS):
             'VIZIO', 'GOOGLE', 'FREESCAL', 'KOBO_INC', 'LENOVO', 'ROCKCHIP',
             'POCKET', 'ONDA_MID', 'ZENITHIN', 'INGENIC', 'PMID701C', 'PD',
             'PMP5097C', 'MASS', 'NOVO7', 'ZEKI', 'COBY', 'SXZ', 'USB_2.0',
-            'COBY_MID', 'VS', 'AINOL', 'TOPWISE', 'PAD703', 'NEXT8D12']
-    WINDOWS_MAIN_MEM = ['ANDROID_PHONE', 'A855', 'A853', 'INC.NEXUS_ONE',
+            'COBY_MID', 'VS', 'AINOL', 'TOPWISE', 'PAD703', 'NEXT8D12',
+            'MEDIATEK', 'KEENHI', 'TECLAST', 'SURFTAB']
+    WINDOWS_MAIN_MEM = ['ANDROID_PHONE', 'A855', 'A853', 'A953', 'INC.NEXUS_ONE',
             '__UMS_COMPOSITE', '_MB200', 'MASS_STORAGE', '_-_CARD', 'SGH-I897',
             'GT-I9000', 'FILE-STOR_GADGET', 'SGH-T959_CARD', 'SGH-T959', 'SAMSUNG_ANDROID',
             'SCH-I500_CARD', 'SPH-D700_CARD', 'MB810', 'GT-P1000', 'DESIRE',
@@ -232,7 +238,8 @@ class ANDROID(USBMS):
             'THINKPAD_TABLET', 'SGH-T989', 'YP-G70', 'STORAGE_DEVICE',
             'ADVANCED', 'SGH-I727', 'USB_FLASH_DRIVER', 'ANDROID',
             'S5830I_CARD', 'MID7042', 'LINK-CREATE', '7035', 'VIEWPAD_7E',
-            'NOVO7', 'MB526', '_USB#WYK7MSF8KE', 'TABLET_PC', 'F']
+            'NOVO7', 'MB526', '_USB#WYK7MSF8KE', 'TABLET_PC', 'F', 'MT65XX_MS',
+            'ICS', 'E400', '__FILE-STOR_GADG', 'ST80208-1']
     WINDOWS_CARD_A_MEM = ['ANDROID_PHONE', 'GT-I9000_CARD', 'SGH-I897',
             'FILE-STOR_GADGET', 'SGH-T959_CARD', 'SGH-T959', 'SAMSUNG_ANDROID', 'GT-P1000_CARD',
             'A70S', 'A101IT', '7', 'INCREDIBLE', 'A7EB', 'SGH-T849_CARD',
@@ -243,7 +250,7 @@ class ANDROID(USBMS):
             'FILE-CD_GADGET', 'GT-I9001_CARD', 'USB_2.0', 'XT875',
             'UMS_COMPOSITE', 'PRO', '.KOBO_VOX', 'SGH-T989_CARD', 'SGH-I727',
             'USB_FLASH_DRIVER', 'ANDROID', 'MID7042', '7035', 'VIEWPAD_7E',
-            'NOVO7', 'ADVANCED', 'TABLET_PC', 'F']
+            'NOVO7', 'ADVANCED', 'TABLET_PC', 'F', 'E400_SD_CARD', 'ST80208-1']
 
     OSX_MAIN_MEM = 'Android Device Main Memory'
 
