@@ -195,7 +195,7 @@ class PRST1(USBMS):
                 for i, row in enumerate(cursor):
                     try:
                         comp_date = int(os.path.getmtime(self.normalize_path(prefix + row[0])) * 1000);
-                    except (OSError, IOError):
+                    except (OSError, IOError, TypeError):
                         # In case the db has incorrect path info
                         continue
                     device_date = int(row[1]);
