@@ -14,6 +14,7 @@ device. This class handles device detection.
 import os, subprocess, time, re, sys, glob
 from itertools import repeat
 
+from calibre import prints, as_unicode
 from calibre.devices.interface import DevicePlugin
 from calibre.devices.errors import DeviceError
 from calibre.devices.usbms.deviceconfig import DeviceConfig
@@ -901,8 +902,11 @@ class Device(DeviceConfig, DevicePlugin):
             for d in drives:
                 try:
                     winutil.eject_drive(bytes(d)[0])
-                except:
-                    pass
+                except Exception as e:
+                    try:
+                        prints("Eject failed:", as_unicode(e))
+                    except:
+                        pass
 
         t = Thread(target=do_it, args=[drives])
         t.daemon = True
