@@ -193,6 +193,26 @@ OptionRecommendation(name='line_height',
             )
         ),
 
+OptionRecommendation(name='embed_font_family',
+        recommended_value=None, level=OptionRecommendation.LOW,
+        help=_(
+            'Embed the specified font family into the book. This specifies '
+            'the "base" font used for the book. If the input document '
+            'specifies its own fonts, they may override this base font. '
+            'You can use the filter style information option to remove fonts from the '
+            'input document. Note that font embedding only works '
+            'with some output formats, principally EPUB and AZW3.')
+        ),
+
+OptionRecommendation(name='subset_embedded_fonts',
+        recommended_value=False, level=OptionRecommendation.LOW,
+        help=_(
+            'Subset all embedded fonts. Every embedded font is reduced '
+            'to contain only the glyphs used in this document. This decreases '
+            'the size of the font files. Useful if you are embedding a '
+            'particularly large font with lots of unused glyphs.')
+        ),
+
 OptionRecommendation(name='linearize_tables',
             recommended_value=False, level=OptionRecommendation.LOW,
             help=_('Some badly designed documents use tables to control the '
@@ -1083,10 +1103,14 @@ OptionRecommendation(name='search_replace',
             from calibre.ebooks.oeb.transforms.unsmarten import UnsmartenPunctuation
             UnsmartenPunctuation()(self.oeb, self.opts)
 
+        mobi_file_type = getattr(self.opts, 'mobi_file_type', 'old')
+        needs_old_markup = (self.output_plugin.file_type == 'lit' or
+                    (self.output_plugin.file_type == 'mobi' and mobi_file_type
+                     == 'old'))
         flattener = CSSFlattener(fbase=fbase, fkey=fkey,
                 lineh=line_height,
-                untable=self.output_plugin.file_type in ('mobi','lit'),
-                unfloat=self.output_plugin.file_type in ('mobi', 'lit'),
+                untable=needs_old_markup,
+                unfloat=needs_old_markup,
                 page_break_on_body=self.output_plugin.file_type in ('mobi',
                     'lit'),
                 specializer=partial(self.output_plugin.specialize_css_for_output,
@@ -1101,6 +1125,10 @@ OptionRecommendation(name='search_replace',
         RemoveFakeMargins()(self.oeb, self.log, self.opts)
         RemoveAdobeMargins()(self.oeb, self.log, self.opts)
 
+        if self.opts.subset_embedded_fonts and self.output_plugin.file_type != 'pdf':
+            from calibre.ebooks.oeb.transforms.subset import SubsetFonts
+            SubsetFonts()(self.oeb, self.log, self.opts)
+
         pr(0.9)
         self.flush()
 
