@@ -120,6 +120,8 @@ class ISBNMerge(object):
                             self.log.debug(xw.tb)
                         else:
                             isbns, min_year = xw.isbns, xw.min_year
+                            if not msprefs['find_first_edition_date']:
+                                min_year = None
                 if not isbns:
                     isbns = frozenset([isbn])
                 if isbns in self.pools:
@@ -481,8 +483,8 @@ def identify(log, abort, # {{{
 
     log('The identify phase took %.2f seconds'%(time.time() - start_time))
     log('The longest time (%f) was taken by:'%longest, lp)
-    log('Merging results from different sources and finding earliest',
-            'publication dates from the xisbn service')
+    log('Merging results from different sources and finding earliest ',
+            'publication dates from the worldcat.org service')
     start_time = time.time()
     results = merge_identify_results(results, log)
 
