@@ -22,9 +22,11 @@ TEMPLATE = '''
   li {{ list-style-type: none }}
   a {{ text-decoration: none }}
   a:hover {{ color: red }}
+  {extra_css}
+  {embed_css}
   </style>
 </head>
-<body>
+<body id="calibre_generated_inline_toc">
 <h2>{title}</h2>
 <ul>
 </ul>
@@ -63,8 +65,16 @@ class TOCAdder(object):
 
         self.log('\tGenerating in-line ToC')
 
+        embed_css = ''
+        s = getattr(oeb, 'store_embed_font_rules', None)
+        if getattr(s, 'body_font_family', None):
+            css = [x.cssText for x in s.rules] + [
+                    'body { font-family: %s }'%s.body_font_family]
+            embed_css = '\n\n'.join(css)
+
         root = etree.fromstring(TEMPLATE.format(xhtmlns=XHTML_NS,
-            title=self.title))
+            title=self.title, embed_css=embed_css,
+            extra_css=(opts.extra_css or '')))
         parent = XPath('//h:ul')(root)[0]
         parent.text = '\n\t'
         for child in self.oeb.toc:
