@@ -372,8 +372,8 @@ class ParseRtf:
         old_rtf = old_rtf_obj.check_if_old_rtf()
         if old_rtf:
             if self.__run_level > 5:
-                msg = 'Older RTF\n'
-                msg += 'self.__run_level is "%s"\n' % self.__run_level
+                msg = 'Older RTF\n' \
+                'self.__run_level is "%s"\n' % self.__run_level
                 raise RtfInvalidCodeException, msg
             if self.__run_level > 1:
                 sys.stderr.write('File could be older RTF...\n')
@@ -381,7 +381,7 @@ class ParseRtf:
                 if self.__run_level > 1:
                     sys.stderr.write(
                         'File also has newer RTF.\n'
-                        'Will do the best to convert.\n'
+                        'Will do the best to convert...\n'
                     )
             add_brackets_obj = add_brackets.AddBrackets(
                     in_file = self.__temp_file,
