@@ -8,7 +8,7 @@ __docformat__ = 'restructuredtext en'
 from functools import partial
 from collections import Counter
 
-from PyQt4.Qt import QObject, QTimer
+from PyQt4.Qt import QObject, QTimer, QModelIndex
 
 from calibre.gui2 import error_dialog, question_dialog
 from calibre.gui2.dialogs.delete_matching_from_device import DeleteMatchingFromDeviceDialog
@@ -285,6 +285,16 @@ class DeleteAction(InterfaceAction):
                 # Current row is after the last row, set it to the last row
                 current_row = view.row_count() - 1
             view.set_current_row(current_row)
+        if view.model().rowCount(QModelIndex()) < 1:
+            self.gui.book_details.reset_info()
+
+    def library_ids_deleted2(self, ids_deleted, next_id=None):
+        view = self.gui.library_view
+        current_row = None
+        if next_id is not None:
+            rmap = view.ids_to_rows([next_id])
+            current_row = rmap.get(next_id, None)
+        self.library_ids_deleted(ids_deleted, current_row=current_row)
 
     def delete_books(self, *args):
         '''
@@ -325,16 +335,13 @@ class DeleteAction(InterfaceAction):
                                    'removed from your calibre library. Are you sure?')
                                 +'</p>', 'library_delete_books', self.gui):
                 return
-            ci = view.currentIndex()
-            row = None
-            if ci.isValid():
-                row = ci.row()
+            next_id = view.next_id
             if len(rows) < 5:
                 view.model().delete_books_by_id(to_delete_ids)
-                self.library_ids_deleted(to_delete_ids, row)
+                self.library_ids_deleted2(to_delete_ids, next_id=next_id)
             else:
                 self.__md = MultiDeleter(self.gui, to_delete_ids,
-                        partial(self.library_ids_deleted, current_row=row))
+                        partial(self.library_ids_deleted2, next_id=next_id))
         # Device view is visible.
         else:
             if self.gui.stack.currentIndex() == 1:
