@@ -93,7 +93,8 @@ class ShareConnMenu(QMenu): # {{{
                     get_external_ip())
             try :
                 cs_port = content_server_config().parse().port
-                ip_text = _(' [%s, port %d]')%(listen_on, cs_port)
+                ip_text = _(' [%(ip)s, port %(port)d]')%dict(ip=listen_on,
+                        port=cs_port)
             except:
                 ip_text = ' [%s]'%listen_on
             text = _('Stop Content Server') + ip_text
@@ -119,17 +120,19 @@ class ShareConnMenu(QMenu): # {{{
             for account in keys:
                 formats, auto, default = opts.accounts[account]
                 subject = opts.subjects.get(account, '')
+                alias = opts.aliases.get(account, '')
                 dest = 'mail:'+account+';'+formats+';'+subject
                 action1 = DeviceAction(dest, False, False, I('mail.png'),
-                        account)
+                        alias or account)
                 action2 = DeviceAction(dest, True, False, I('mail.png'),
-                        account + ' ' + _('(delete from library)'))
+                        (alias or account) + ' ' + _('(delete from library)'))
                 self.email_to_menu.addAction(action1)
                 self.email_to_and_delete_menu.addAction(action2)
                 map(self.memory.append, (action1, action2))
                 if default:
                     ac = DeviceAction(dest, False, False,
-                            I('mail.png'), _('Email to') + ' ' +account)
+                            I('mail.png'), _('Email to') + ' ' +(alias or
+                                account))
                     self.addAction(ac)
                     self.email_actions.append(ac)
                     ac.a_s.connect(sync_menu.action_triggered)
