@@ -7,15 +7,18 @@ __license__   = 'GPL v3'
 __copyright__ = '2011, Kovid Goyal <kovid@kovidgoyal.net>'
 __docformat__ = 'restructuredtext en'
 
+import os
+
 from PyQt4.Qt import (QWidget, QDialog, QLabel, QGridLayout, QComboBox, QSize,
         QLineEdit, QIntValidator, QDoubleValidator, QFrame, QColor, Qt, QIcon,
         QScrollArea, QPushButton, QVBoxLayout, QDialogButtonBox, QToolButton,
         QListView, QAbstractListModel, pyqtSignal, QSizePolicy, QSpacerItem,
         QApplication)
 
-from calibre import prepare_string_for_xml
+from calibre import prepare_string_for_xml, sanitize_file_name_unicode
+from calibre.constants import config_dir
 from calibre.utils.icu import sort_key
-from calibre.gui2 import error_dialog
+from calibre.gui2 import error_dialog, choose_files, pixmap_to_data
 from calibre.gui2.dialogs.template_dialog import TemplateDialog
 from calibre.gui2.metadata.single_download import RichTextDelegate
 from calibre.library.coloring import (Rule, conditionable_columns,
@@ -25,6 +28,9 @@ from calibre.utils.icu import lower
 
 all_columns_string = _('All Columns')
 
+icon_rule_kinds = [(_('icon with text'), 'icon'),
+                   (_('icon with no text'), 'icon_only') ]
+
 class ConditionEditor(QWidget): # {{{
 
     ACTION_MAP = {
@@ -46,6 +52,12 @@ class ConditionEditor(QWidget): # {{{
                 (_('is less than'), 'lt'),
                 (_('is greater than'), 'gt')
             ),
+            'datetime' : (
+                (_('is equal to'), 'eq'),
+                (_('is less than'), 'lt'),
+                (_('is greater than'), 'gt'),
+                (_('is not more days ago than'), 'count_days')
+            ),
             'multiple' : (
                 (_('has'), 'has'),
                 (_('does not have'), 'does not have'),
@@ -64,7 +76,7 @@ class ConditionEditor(QWidget): # {{{
             ),
     }
 
-    for x in ('float', 'rating', 'datetime'):
+    for x in ('float', 'rating'):
         ACTION_MAP[x] = ACTION_MAP['int']
 
 
@@ -106,8 +118,8 @@ class ConditionEditor(QWidget): # {{{
         self.column_box.addItem('', '')
         for key in sorted(
                 conditionable_columns(fm),
-                key=sort_key):
-            self.column_box.addItem(key, key)
+                key=lambda(key): sort_key(fm[key]['name'])):
+            self.column_box.addItem(fm[key]['name'], key)
         self.column_box.setCurrentIndex(0)
 
         self.column_box.currentIndexChanged.connect(self.init_action_box)
@@ -207,8 +219,6 @@ class ConditionEditor(QWidget): # {{{
         col = self.current_col
         if not col:
             return
-        m = self.fm[col]
-        dt = m['datatype']
         action = self.current_action
         if not action:
             return
@@ -228,8 +238,12 @@ class ConditionEditor(QWidget): # {{{
             v = QIntValidator if dt == 'int' else QDoubleValidator
             self.value_box.setValidator(v(self.value_box))
         elif dt == 'datetime':
-            self.value_box.setInputMask('9999-99-99')
-            tt = _('Enter a date in the format YYYY-MM-DD')
+            if action == 'count_days':
+                self.value_box.setValidator(QIntValidator(self.value_box))
+                tt = _('Enter the number of days old the item can be. Zero is today')
+            else:
+                self.value_box.setInputMask('9999-99-99')
+                tt = _('Enter a date in the format YYYY-MM-DD')
         else:
             tt = _('Enter a string.')
             if 'pattern' in action:
@@ -245,64 +259,103 @@ class ConditionEditor(QWidget): # {{{
 
 class RuleEditor(QDialog): # {{{
 
-    def __init__(self, fm, parent=None):
+    def __init__(self, fm, pref_name, parent=None):
         QDialog.__init__(self, parent)
         self.fm = fm
 
+        if pref_name == 'column_color_rules':
+            self.rule_kind = 'color'
+            rule_text = _('coloring')
+        else:
+            self.rule_kind = 'icon'
+            rule_text = _('icon')
+
         self.setWindowIcon(QIcon(I('format-fill-color.png')))
-        self.setWindowTitle(_('Create/edit a column coloring rule'))
+        self.setWindowTitle(_('Create/edit a column {0} rule').format(rule_text))
 
         self.l = l = QGridLayout(self)
         self.setLayout(l)
 
-        self.l1 = l1 = QLabel(_('Create a coloring rule by'
-            ' filling in the boxes below'))
-        l.addWidget(l1, 0, 0, 1, 5)
+        self.l1 = l1 = QLabel(_('Create a column {0} rule by'
+            ' filling in the boxes below'.format(rule_text)))
+        l.addWidget(l1, 0, 0, 1, 8)
 
         self.f1 = QFrame(self)
         self.f1.setFrameShape(QFrame.HLine)
-        l.addWidget(self.f1, 1, 0, 1, 5)
+        l.addWidget(self.f1, 1, 0, 1, 8)
 
-        self.l2 = l2 = QLabel(_('Set the color of the column:'))
+        self.l2 = l2 = QLabel(_('Set the'))
         l.addWidget(l2, 2, 0)
 
-        self.column_box = QComboBox(self)
-        l.addWidget(self.column_box, 2, 1)
+        if self.rule_kind == 'color':
+            l.addWidget(QLabel(_('color')))
+        else:
+            self.kind_box = QComboBox(self)
+            for tt, t in icon_rule_kinds:
+                self.kind_box.addItem(tt, t)
+            l.addWidget(self.kind_box, 2, 1)
 
-        self.l3 = l3 = QLabel(_('to'))
+        self.l3 = l3 = QLabel(_('of the column:'))
         l.addWidget(l3, 2, 2)
 
-        self.color_box = QComboBox(self)
-        self.color_label = QLabel('Sample text Sample text')
-        self.color_label.setTextFormat(Qt.RichText)
-        l.addWidget(self.color_box, 2, 3)
-        l.addWidget(self.color_label, 2, 4)
-        l.addItem(QSpacerItem(10, 10, QSizePolicy.Expanding), 2, 5)
+        self.column_box = QComboBox(self)
+        l.addWidget(self.column_box, 2, 3)
 
-        self.l4 = l4 = QLabel(
+        self.l4 = l4 = QLabel(_('to'))
+        l.addWidget(l4, 2, 4)
+
+        if self.rule_kind == 'color':
+            self.color_box = QComboBox(self)
+            self.color_label = QLabel('Sample text Sample text')
+            self.color_label.setTextFormat(Qt.RichText)
+            l.addWidget(self.color_box, 2, 5)
+            l.addWidget(self.color_label, 2, 6)
+            l.addItem(QSpacerItem(10, 10, QSizePolicy.Expanding), 2, 7)
+        else:
+            self.filename_box = QComboBox()
+            self.filename_box.setInsertPolicy(self.filename_box.InsertAlphabetically)
+            d = os.path.join(config_dir, 'cc_icons')
+            self.icon_file_names = []
+            if os.path.exists(d):
+                for icon_file in os.listdir(d):
+                    icon_file = lower(icon_file)
+                    if os.path.exists(os.path.join(d, icon_file)):
+                        if icon_file.endswith('.png'):
+                            self.icon_file_names.append(icon_file)
+            self.icon_file_names.sort(key=sort_key)
+            self.update_filename_box()
+
+            l.addWidget(self.filename_box, 2, 5)
+            self.filename_button = QPushButton(QIcon(I('document_open.png')),
+                                               _('&Add icon'))
+            l.addWidget(self.filename_button, 2, 6)
+            l.addWidget(QLabel(_('Icons should be square or landscape')), 2, 7)
+            l.setColumnStretch(7, 10)
+
+        self.l5 = l5 = QLabel(
             _('Only if the following conditions are all satisfied:'))
-        l.addWidget(l4, 3, 0, 1, 6)
+        l.addWidget(l5, 3, 0, 1, 7)
 
         self.scroll_area = sa = QScrollArea(self)
         sa.setMinimumHeight(300)
         sa.setMinimumWidth(950)
         sa.setWidgetResizable(True)
-        l.addWidget(sa, 4, 0, 1, 6)
+        l.addWidget(sa, 4, 0, 1, 8)
 
         self.add_button = b = QPushButton(QIcon(I('plus.png')),
                 _('Add another condition'))
-        l.addWidget(b, 5, 0, 1, 6)
+        l.addWidget(b, 5, 0, 1, 8)
         b.clicked.connect(self.add_blank_condition)
 
-        self.l5 = l5 = QLabel(_('You can disable a condition by'
+        self.l6 = l6 = QLabel(_('You can disable a condition by'
             ' blanking all of its boxes'))
-        l.addWidget(l5, 6, 0, 1, 6)
+        l.addWidget(l6, 6, 0, 1, 8)
 
         self.bb = bb = QDialogButtonBox(
                 QDialogButtonBox.Ok|QDialogButtonBox.Cancel)
         bb.accepted.connect(self.accept)
         bb.rejected.connect(self.reject)
-        l.addWidget(bb, 7, 0, 1, 6)
+        l.addWidget(bb, 7, 0, 1, 8)
 
         self.conditions_widget = QWidget(self)
         sa.setWidget(self.conditions_widget)
@@ -310,23 +363,39 @@ class RuleEditor(QDialog): # {{{
         self.conditions_widget.layout().setAlignment(Qt.AlignTop)
         self.conditions = []
 
-        for b in (self.column_box, self.color_box):
-            b.setSizeAdjustPolicy(b.AdjustToMinimumContentsLengthWithIcon)
-            b.setMinimumContentsLength(15)
+        if self.rule_kind == 'color':
+            for b in (self.column_box, self.color_box):
+                b.setSizeAdjustPolicy(b.AdjustToMinimumContentsLengthWithIcon)
+                b.setMinimumContentsLength(15)
 
-        for key in sorted(displayable_columns(fm), key=sort_key):
+        for key in sorted(displayable_columns(fm),
+                          key=lambda(k): sort_key(fm[k]['name']) if k != color_row_key else 0):
+            if key == color_row_key and self.rule_kind != 'color':
+                continue
             name = all_columns_string if key == color_row_key else fm[key]['name']
             if name:
                 self.column_box.addItem(name, key)
         self.column_box.setCurrentIndex(0)
 
-        self.color_box.addItems(QColor.colorNames())
-        self.color_box.setCurrentIndex(0)
+        if self.rule_kind == 'color':
+            self.color_box.addItems(QColor.colorNames())
+            self.color_box.setCurrentIndex(0)
+            self.update_color_label()
+            self.color_box.currentIndexChanged.connect(self.update_color_label)
+        else:
+            self.filename_button.clicked.connect(self.filename_button_clicked)
 
-        self.update_color_label()
-        self.color_box.currentIndexChanged.connect(self.update_color_label)
         self.resize(self.sizeHint())
 
+    def update_filename_box(self):
+        self.filename_box.clear()
+        self.icon_file_names.sort(key=sort_key)
+        self.filename_box.addItem('')
+        self.filename_box.addItems(self.icon_file_names)
+        for i,filename in enumerate(self.icon_file_names):
+            icon = QIcon(os.path.join(config_dir, 'cc_icons', filename))
+            self.filename_box.setItemIcon(i+1, icon)
+
     def update_color_label(self):
         pal = QApplication.palette()
         bg1 = unicode(pal.color(pal.Base).name())
@@ -337,22 +406,64 @@ class RuleEditor(QDialog): # {{{
             <span style="color: {c}; background-color: {bg2}">&nbsp;{st}&nbsp;</span>
             '''.format(c=c, bg1=bg1, bg2=bg2, st=_('Sample Text')))
 
+    def filename_button_clicked(self):
+        try:
+            path = choose_files(self, 'choose_category_icon',
+                        _('Select Icon'), filters=[
+                        ('Images', ['png', 'gif', 'jpg', 'jpeg'])],
+                    all_files=False, select_only_single_file=True)
+            if path:
+                icon_path = path[0]
+                icon_name = sanitize_file_name_unicode(
+                             os.path.splitext(
+                                   os.path.basename(icon_path))[0]+'.png')
+                if icon_name not in self.icon_file_names:
+                    self.icon_file_names.append(icon_name)
+                    self.update_filename_box()
+                    try:
+                        p = QIcon(icon_path).pixmap(QSize(128, 128))
+                        d = os.path.join(config_dir, 'cc_icons')
+                        if not os.path.exists(os.path.join(d, icon_name)):
+                            if not os.path.exists(d):
+                                os.makedirs(d)
+                            with open(os.path.join(d, icon_name), 'wb') as f:
+                                f.write(pixmap_to_data(p, format='PNG'))
+                    except:
+                        import traceback
+                        traceback.print_exc()
+                self.filename_box.setCurrentIndex(self.filename_box.findText(icon_name))
+                self.filename_box.adjustSize()
+        except:
+            import traceback
+            traceback.print_exc()
+        return
 
     def add_blank_condition(self):
         c = ConditionEditor(self.fm, parent=self.conditions_widget)
         self.conditions.append(c)
         self.conditions_widget.layout().addWidget(c)
 
-    def apply_rule(self, col, rule):
+    def apply_rule(self, kind, col, rule):
+        if kind == 'color':
+            if rule.color:
+                idx = self.color_box.findText(rule.color)
+                if idx >= 0:
+                    self.color_box.setCurrentIndex(idx)
+        else:
+            self.kind_box.setCurrentIndex(0 if kind == 'icon' else 1)
+            if rule.color:
+                idx = self.filename_box.findText(rule.color)
+                if idx >= 0:
+                    self.filename_box.setCurrentIndex(idx)
+                else:
+                    self.filename_box.setCurrentIndex(0)
+
         for i in range(self.column_box.count()):
             c = unicode(self.column_box.itemData(i).toString())
             if col == c:
                 self.column_box.setCurrentIndex(i)
                 break
-        if rule.color:
-            idx = self.color_box.findText(rule.color)
-            if idx >= 0:
-                self.color_box.setCurrentIndex(idx)
+
         for c in rule.conditions:
             ce = ConditionEditor(self.fm, parent=self.conditions_widget)
             self.conditions.append(ce)
@@ -365,6 +476,12 @@ class RuleEditor(QDialog): # {{{
 
 
     def accept(self):
+        if self.rule_kind != 'color':
+            fname = lower(unicode(self.filename_box.currentText()))
+            if not fname:
+                error_dialog(self, _('No icon selected'),
+                        _('You must choose an icon for this rule'), show=True)
+                return
         if self.validate():
             QDialog.accept(self)
 
@@ -392,31 +509,54 @@ class RuleEditor(QDialog): # {{{
     @property
     def rule(self):
         r = Rule(self.fm)
-        r.color = unicode(self.color_box.currentText())
+        if self.rule_kind != 'color':
+            r.color = unicode(self.filename_box.currentText())
+        else:
+            r.color = unicode(self.color_box.currentText())
         idx = self.column_box.currentIndex()
         col = unicode(self.column_box.itemData(idx).toString())
         for c in self.conditions:
             condition = c.condition
             if condition is not None:
                 r.add_condition(*condition)
+        if self.rule_kind == 'icon':
+            kind = unicode(self.kind_box.itemData(
+                                    self.kind_box.currentIndex()).toString())
+        else:
+            kind = 'color'
 
-        return col, r
+        return kind, col, r
 # }}}
 
 class RulesModel(QAbstractListModel): # {{{
 
-    def __init__(self, prefs, fm, parent=None):
+    def __init__(self, prefs, fm, pref_name, parent=None):
         QAbstractListModel.__init__(self, parent)
 
         self.fm = fm
-        rules = list(prefs['column_color_rules'])
-        self.rules = []
-        for col, template in rules:
-            try:
-                rule = rule_from_template(self.fm, template)
-            except:
-                rule = template
-            self.rules.append((col, rule))
+        self.pref_name = pref_name
+        if pref_name == 'column_color_rules':
+            self.rule_kind = 'color'
+            rules = list(prefs[pref_name])
+            self.rules = []
+            for col, template in rules:
+                if col not in self.fm and col != color_row_key: continue
+                try:
+                    rule = rule_from_template(self.fm, template)
+                except:
+                    rule = template
+                self.rules.append(('color', col, rule))
+        else:
+            self.rule_kind = 'icon'
+            rules = list(prefs[pref_name])
+            self.rules = []
+            for kind, col, template in rules:
+                if col not in self.fm and col != color_row_key: continue
+                try:
+                    rule = rule_from_template(self.fm, template)
+                except:
+                    rule = template
+                self.rules.append((kind, col, rule))
 
     def rowCount(self, *args):
         return len(self.rules)
@@ -424,23 +564,25 @@ class RulesModel(QAbstractListModel): # {{{
     def data(self, index, role):
         row = index.row()
         try:
-            col, rule = self.rules[row]
+            kind, col, rule = self.rules[row]
         except:
             return None
-        if col == color_row_key:
-            col = all_columns_string
         if role == Qt.DisplayRole:
-            return self.rule_to_html(col, rule)
+            if col == color_row_key:
+                col = all_columns_string
+            else:
+                col = self.fm[col]['name']
+            return self.rule_to_html(kind, col, rule)
         if role == Qt.UserRole:
-            return (col, rule)
+            return (kind, col, rule)
 
-    def add_rule(self, col, rule):
-        self.rules.append((col, rule))
+    def add_rule(self, kind, col, rule):
+        self.rules.append((kind, col, rule))
         self.reset()
         return self.index(len(self.rules)-1)
 
-    def replace_rule(self, index, col, r):
-        self.rules[index.row()] = (col, r)
+    def replace_rule(self, index, kind, col, r):
+        self.rules[index.row()] = (kind, col, r)
         self.dataChanged.emit(index, index)
 
     def remove_rule(self, index):
@@ -449,12 +591,15 @@ class RulesModel(QAbstractListModel): # {{{
 
     def commit(self, prefs):
         rules = []
-        for col, r in self.rules:
+        for kind, col, r in self.rules:
             if isinstance(r, Rule):
                 r = r.template
             if r is not None:
-                rules.append((col, r))
-        prefs['column_color_rules'] = rules
+                if kind == 'color':
+                    rules.append((col, r))
+                else:
+                    rules.append((kind, col, r))
+        prefs[self.pref_name] = rules
 
     def move(self, idx, delta):
         row = idx.row() + delta
@@ -471,21 +616,32 @@ class RulesModel(QAbstractListModel): # {{{
         self.rules = []
         self.reset()
 
-    def rule_to_html(self, col, rule):
+    def rule_to_html(self, kind, col, rule):
         if not isinstance(rule, Rule):
             return _('''
             <p>Advanced Rule for column <b>%(col)s</b>:
             <pre>%(rule)s</pre>
             ''')%dict(col=col, rule=prepare_string_for_xml(rule))
         conditions = [self.condition_to_html(c) for c in rule.conditions]
+
+        trans_kind = 'not found'
+        if kind == 'color':
+            trans_kind = _('color')
+        else:
+            for tt, t in icon_rule_kinds:
+                if kind == t:
+                    trans_kind = tt
+                    break
+
         return _('''\
-            <p>Set the color of <b>%(col)s</b> to <b>%(color)s</b> if the following
+            <p>Set the <b>%(kind)s</b> of <b>%(col)s</b> to <b>%(color)s</b> if the following
             conditions are met:</p>
             <ul>%(rule)s</ul>
-            ''') % dict(col=col, color=rule.color, rule=''.join(conditions))
+            ''') % dict(kind=trans_kind, col=col, color=rule.color, rule=''.join(conditions))
 
     def condition_to_html(self, condition):
         c, a, v = condition
+        c = self.fm[c]['name']
         action_name = a
         for actions in ConditionEditor.ACTION_MAP.itervalues():
             for trans, ac in actions:
@@ -508,12 +664,7 @@ class EditRules(QWidget): # {{{
         self.l = l = QGridLayout(self)
         self.setLayout(l)
 
-        self.l1 = l1 = QLabel('<p>'+_(
-            'You can control the color of columns in the'
-            ' book list by creating "rules" that tell calibre'
-            ' what color to use. Click the Add Rule button below'
-            ' to get started.<p>You can <b>change an existing rule</b> by double'
-            ' clicking it.'))
+        self.l1 = l1 = QLabel('')
         l1.setWordWrap(True)
         l.addWidget(l1, 0, 0, 1, 2)
 
@@ -554,24 +705,40 @@ class EditRules(QWidget): # {{{
         b.clicked.connect(self.add_advanced)
         l.addWidget(b, 3, 0, 1, 2)
 
-    def initialize(self, fm, prefs, mi):
-        self.model = RulesModel(prefs, fm)
+    def initialize(self, fm, prefs, mi, pref_name):
+        self.pref_name = pref_name
+        self.model = RulesModel(prefs, fm, self.pref_name)
         self.rules_view.setModel(self.model)
         self.fm = fm
         self.mi = mi
+        if pref_name == 'column_color_rules':
+            self.l1.setText('<p>'+_(
+                'You can control the color of columns in the'
+                ' book list by creating "rules" that tell calibre'
+                ' what color to use. Click the Add Rule button below'
+                ' to get started.<p>You can <b>change an existing rule</b> by'
+                ' double clicking it.'))
+        else:
+            self.l1.setText('<p>'+_(
+                'You can add icons to columns in the'
+                ' book list by creating "rules" that tell calibre'
+                ' what icon to use. Click the Add Rule button below'
+                ' to get started.<p>You can <b>change an existing rule</b> by'
+                ' double clicking it.'))
+            self.add_advanced_button.setVisible(False)
 
     def _add_rule(self, dlg):
         if dlg.exec_() == dlg.Accepted:
-            col, r = dlg.rule
-            if r and col:
-                idx = self.model.add_rule(col, r)
+            kind, col, r = dlg.rule
+            if kind and r and col:
+                idx = self.model.add_rule(kind, col, r)
                 self.rules_view.scrollTo(idx)
                 self.changed.emit()
 
     def add_rule(self):
-            d = RuleEditor(self.model.fm)
-            d.add_blank_condition()
-            self._add_rule(d)
+        d = RuleEditor(self.model.fm, self.pref_name)
+        d.add_blank_condition()
+        self._add_rule(d)
 
     def add_advanced(self):
         td = TemplateDialog(self, '', mi=self.mi, fm=self.fm, color_field='')
@@ -579,18 +746,18 @@ class EditRules(QWidget): # {{{
 
     def edit_rule(self, index):
         try:
-            col, rule = self.model.data(index, Qt.UserRole)
+            kind, col, rule = self.model.data(index, Qt.UserRole)
         except:
             return
         if isinstance(rule, Rule):
-            d = RuleEditor(self.model.fm)
-            d.apply_rule(col, rule)
+            d = RuleEditor(self.model.fm, self.pref_name)
+            d.apply_rule(kind, col, rule)
         else:
             d = TemplateDialog(self, rule, mi=self.mi, fm=self.fm, color_field=col)
         if d.exec_() == d.Accepted:
-            col, r = d.rule
-            if r is not None and col:
-                self.model.replace_rule(index, col, r)
+            kind, col, r = d.rule
+            if kind and r is not None and col:
+                self.model.replace_rule(index, kind, col, r)
                 self.rules_view.scrollTo(index)
                 self.changed.emit()
 
@@ -646,7 +813,7 @@ if __name__ == '__main__':
     db = db()
 
     if True:
-        d = RuleEditor(db.field_metadata)
+        d = RuleEditor(db.field_metadata, 'column_color_rules')
         d.add_blank_condition()
         d.exec_()
 
