@@ -236,6 +236,8 @@ class EbookViewer(MainWindow, Ui_EbookViewer):
         self.action_copy.triggered[bool].connect(self.copy)
         self.action_font_size_larger.triggered.connect(self.font_size_larger)
         self.action_font_size_smaller.triggered.connect(self.font_size_smaller)
+        self.action_font_size_larger.setShortcut(Qt.CTRL+Qt.Key_Equal)
+        self.action_font_size_smaller.setShortcut(Qt.CTRL+Qt.Key_Minus)
         self.action_open_ebook.triggered[bool].connect(self.open_ebook)
         self.action_next_page.triggered.connect(self.view.next_page)
         self.action_previous_page.triggered.connect(self.view.previous_page)
@@ -303,6 +305,7 @@ class EbookViewer(MainWindow, Ui_EbookViewer):
         self.toggle_toolbar_action = QAction(_('Show/hide controls'), self)
         self.toggle_toolbar_action.setCheckable(True)
         self.toggle_toolbar_action.triggered.connect(self.toggle_toolbars)
+        self.toolbar_hidden = None
         self.addAction(self.toggle_toolbar_action)
         self.full_screen_label_anim = QPropertyAnimation(
                 self.full_screen_label, 'size')
@@ -359,7 +362,10 @@ class EbookViewer(MainWindow, Ui_EbookViewer):
                 # continue to function even when the toolbars are hidden
                 self.addAction(action)
 
+        self.view.document.settings_changed.connect(self.settings_changed)
+
         self.restore_state()
+        self.settings_changed()
         self.action_toggle_paged_mode.toggled[bool].connect(self.toggle_paged_mode)
         if (start_in_fullscreen or self.view.document.start_in_fullscreen):
             self.action_full_screen.trigger()
@@ -373,6 +379,11 @@ class EbookViewer(MainWindow, Ui_EbookViewer):
         if at_start: return
         self.reload()
 
+    def settings_changed(self):
+        for x in ('', '2'):
+            x = getattr(self, 'tool_bar'+x)
+            x.setVisible(self.view.document.show_controls)
+
     def reload(self):
         if hasattr(self, 'current_index') and self.current_index > -1:
             self.view.document.page_position.save(overwrite=False)
@@ -575,8 +586,7 @@ class EbookViewer(MainWindow, Ui_EbookViewer):
         self.vertical_scrollbar.setVisible(True)
         self.window_mode_changed = 'normal'
         self.esc_full_screen_action.setEnabled(False)
-        self.tool_bar.setVisible(True)
-        self.tool_bar2.setVisible(True)
+        self.settings_changed()
         self.full_screen_label.setVisible(False)
         if hasattr(self, '_original_frame_margins'):
             om = self._original_frame_margins
@@ -697,11 +707,13 @@ class EbookViewer(MainWindow, Ui_EbookViewer):
         self.view.shrink_fonts()
 
     def magnification_changed(self, val):
-        tt = _('Make font size %(which)s\nCurrent magnification: %(mag).1f')
+        tt = _('%(which)s font size [%(sc)s]\nCurrent magnification: %(mag).1f')
+        sc = unicode(self.action_font_size_larger.shortcut().toString())
         self.action_font_size_larger.setToolTip(
-                tt %dict(which=_('larger'), mag=val))
+                tt %dict(which=_('Increase'), mag=val, sc=sc))
+        sc = unicode(self.action_font_size_smaller.shortcut().toString())
         self.action_font_size_smaller.setToolTip(
-                tt %dict(which=_('smaller'), mag=val))
+                tt %dict(which=_('Decrease'), mag=val, sc=sc))
         self.action_font_size_larger.setEnabled(self.view.multiplier < 3)
         self.action_font_size_smaller.setEnabled(self.view.multiplier > 0.2)
 
@@ -758,7 +770,7 @@ class EbookViewer(MainWindow, Ui_EbookViewer):
                     self.view.scroll_to(frag)
                 else:
                     # Scroll to top
-                    self.view.scroll_to('#')
+                    self.view.scroll_to(0)
                 if self.view.document.ypos == oldpos:
                     # If we are coming from goto_next_section() call this will
                     # cause another goto next section call with the next toc
