@@ -3,18 +3,16 @@ __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
 '''
 Miscellaneous widgets used in the GUI
 '''
-import re, traceback, os
+import re, os
 
 from PyQt4.Qt import (QIcon, QFont, QLabel, QListWidget, QAction,
         QListWidgetItem, QTextCharFormat, QApplication, QSyntaxHighlighter,
         QCursor, QColor, QWidget, QPixmap, QSplitterHandle, QToolButton,
-        QAbstractListModel, QVariant, Qt, SIGNAL, pyqtSignal, QRegExp, QSize,
-        QSplitter, QPainter, QLineEdit, QComboBox, QPen, QGraphicsScene, QMenu,
-        QStringListModel, QCompleter, QStringList, QTimer, QRect,
-        QFontDatabase, QGraphicsView, QByteArray)
+        QVariant, Qt, SIGNAL, pyqtSignal, QRegExp, QSize, QSplitter, QPainter,
+        QLineEdit, QComboBox, QPen, QGraphicsScene, QMenu, QStringListModel,
+        QCompleter, QStringList, QTimer, QRect, QGraphicsView, QByteArray)
 
-from calibre.constants import iswindows
-from calibre.gui2 import (NONE, error_dialog, pixmap_to_data, gprefs,
+from calibre.gui2 import (error_dialog, pixmap_to_data, gprefs,
         warning_dialog)
 from calibre.gui2.filename_pattern_ui import Ui_Form
 from calibre import fit_image
@@ -285,6 +283,7 @@ class ImageView(QWidget, ImageDropMixin): # {{{
         self.setMinimumSize(QSize(150, 200))
         ImageDropMixin.__init__(self)
         self.draw_border = True
+        self.show_size = False
 
     def setPixmap(self, pixmap):
         if not isinstance(pixmap, QPixmap):
@@ -307,6 +306,7 @@ class ImageView(QWidget, ImageDropMixin): # {{{
         if pmap.isNull():
             return
         w, h = pmap.width(), pmap.height()
+        ow, oh = w, h
         cw, ch = self.rect().width(), self.rect().height()
         scaled, nw, nh = fit_image(w, h, cw, ch)
         if scaled:
@@ -319,12 +319,22 @@ class ImageView(QWidget, ImageDropMixin): # {{{
         p = QPainter(self)
         p.setRenderHints(QPainter.Antialiasing | QPainter.SmoothPixmapTransform)
         p.drawPixmap(target, pmap)
-        pen = QPen()
-        pen.setWidth(self.BORDER_WIDTH)
-        p.setPen(pen)
         if self.draw_border:
+            pen = QPen()
+            pen.setWidth(self.BORDER_WIDTH)
+            p.setPen(pen)
             p.drawRect(target)
-        #p.drawRect(self.rect())
+        if self.show_size:
+            sztgt = target.adjusted(0, 0, 0, -4)
+            f = p.font()
+            f.setBold(True)
+            p.setFont(f)
+            sz = u'\u00a0%d x %d\u00a0'%(ow, oh)
+            flags = Qt.AlignBottom|Qt.AlignRight|Qt.TextSingleLine
+            szrect = p.boundingRect(sztgt, flags, sz)
+            p.fillRect(szrect.adjusted(0, 0, 0, 4), QColor(0, 0, 0, 200))
+            p.setPen(QPen(QColor(255,255,255)))
+            p.drawText(sztgt, flags, sz)
         p.end()
 # }}}
 
@@ -348,46 +358,6 @@ class CoverView(QGraphicsView, ImageDropMixin): # {{{
 
 # }}}
 
-class FontFamilyModel(QAbstractListModel): # {{{
-
-    def __init__(self, *args):
-        QAbstractListModel.__init__(self, *args)
-        from calibre.utils.fonts import fontconfig
-        try:
-            self.families = fontconfig.find_font_families()
-        except:
-            self.families = []
-            print 'WARNING: Could not load fonts'
-            traceback.print_exc()
-        # Restrict to Qt families as Qt tends to crash
-        qt_families = set([unicode(x) for x in QFontDatabase().families()])
-        self.families = list(qt_families.intersection(set(self.families)))
-        self.families.sort()
-        self.families[:0] = [_('None')]
-        self.font = QFont('Arial' if iswindows else 'sansserif')
-
-    def rowCount(self, *args):
-        return len(self.families)
-
-    def data(self, index, role):
-        try:
-            family = self.families[index.row()]
-        except:
-            traceback.print_exc()
-            return NONE
-        if role == Qt.DisplayRole:
-            return QVariant(family)
-        if role == Qt.FontRole:
-            # If a user chooses some non standard font as the interface font,
-            # rendering some font names causes Qt to crash, so return what is
-            # hopefully a "safe" font
-            return QVariant(self.font)
-        return NONE
-
-    def index_of(self, family):
-        return self.families.index(family.strip())
-# }}}
-
 # BasicList {{{
 class BasicListItem(QListWidgetItem):
 
@@ -624,6 +594,9 @@ class HistoryLineEdit(QComboBox): # {{{
         self.setInsertPolicy(self.NoInsert)
         self.setMaxCount(10)
 
+    def setPlaceholderText(self, txt):
+        return self.lineEdit().setPlaceholderText(txt)
+
     @property
     def store_name(self):
         return 'lineedit_history_'+self._name
