@@ -197,7 +197,8 @@ class NookColor(Nook):
 
 class NookTablet(NookColor):
     id = 'nook_tablet'
-    name = 'Nook Tablet'
+    name = 'Nook Tablet/HD'
+    output_profile = 'nook_hd_plus'
 
 class CybookG3(Device):
 
@@ -245,6 +246,13 @@ class PocketBook900(PocketBook):
     id = 'pocketbook900'
     output_profile = 'pocketbook_900'
 
+class PocketBookPro912(PocketBook):
+
+    name = 'PocketBook Pro 912'
+    id = 'pocketbookpro912'
+    output_profile = 'pocketbook_pro_912'
+
+
 class iPhone(Device):
 
     name = 'iPhone/iTouch'
