@@ -23,13 +23,16 @@ FIELDS = set(['title', 'authors', 'author_sort', 'publisher', 'rating',
     'formats', 'isbn', 'uuid', 'pubdate', 'cover', 'last_modified',
     'identifiers'])
 
+do_notify = True
 def send_message(msg=''):
+    global do_notify
+    if not do_notify:
+        return
     prints('Notifying calibre of the change')
     from calibre.utils.ipc import RC
-    import time
     t = RC(print_error=False)
     t.start()
-    time.sleep(3)
+    t.join(3)
     if t.done:
         t.conn.send('refreshdb:'+msg)
         t.conn.close()
@@ -42,22 +45,27 @@ def get_parser(usage):
     parser = OptionParser(usage)
     go = parser.add_option_group(_('GLOBAL OPTIONS'))
     go.add_option('--library-path', '--with-library', default=None, help=_('Path to the calibre library. Default is to use the path stored in the settings.'))
+    go.add_option('--dont-notify-gui', default=False, action='store_true',
+            help=_('Do not notify the running calibre GUI (if any) that the database has'
+                ' changed. Use with care, as it can lead to database corruption!'))
 
     return parser
 
 def get_db(dbpath, options):
+    global do_notify
     if options.library_path is not None:
         dbpath = options.library_path
     if dbpath is None:
         raise ValueError('No saved library path, either run the GUI or use the'
                 ' --with-library option')
     dbpath = os.path.abspath(dbpath)
+    if options.dont_notify_gui:
+        do_notify = False
     return LibraryDatabase2(dbpath)
 
 def do_list(db, fields, afields, sort_by, ascending, search_text, line_width, separator,
             prefix, subtitle='Books in the calibre database'):
-    from calibre.constants import terminal_controller as tc
-    terminal_controller = tc()
+    from calibre.utils.terminal import ColoredStream, geometry
     if sort_by:
         db.sort(sort_by, ascending)
     if search_text:
@@ -92,7 +100,7 @@ def do_list(db, fields, afields, sort_by, ascending, search_text, line_width, se
         for j, field in enumerate(fields):
             widths[j] = max(widths[j], len(unicode(i[field])))
 
-    screen_width = terminal_controller.COLS if line_width < 0 else line_width
+    screen_width = geometry()[0] if line_width < 0 else line_width
     if not screen_width:
         screen_width = 80
     field_width = screen_width//len(fields)
@@ -111,7 +119,8 @@ def do_list(db, fields, afields, sort_by, ascending, search_text, line_width, se
     widths = list(base_widths)
     titles = map(lambda x, y: '%-*s%s'%(x-len(separator), y, separator),
             widths, title_fields)
-    print terminal_controller.GREEN + ''.join(titles)+terminal_controller.NORMAL
+    with ColoredStream(sys.stdout, fg='green'):
+        print ''.join(titles)
 
     wrappers = map(lambda x: TextWrapper(x-1), widths)
     o = cStringIO.StringIO()
@@ -206,7 +215,7 @@ class DevNull(object):
 NULL = DevNull()
 
 def do_add(db, paths, one_book_per_directory, recurse, add_duplicates, otitle,
-        oauthors, oisbn, otags, oseries, oseries_index):
+        oauthors, oisbn, otags, oseries, oseries_index, ocover):
     orig = sys.stdout
     #sys.stdout = NULL
     try:
@@ -238,6 +247,8 @@ def do_add(db, paths, one_book_per_directory, recurse, add_duplicates, otitle,
                 if val: setattr(mi, x, val)
             if oseries:
                 mi.series_index = oseries_index
+            if ocover:
+                mi.cover = ocover
 
             formats.append(format)
             metadata.append(mi)
@@ -326,11 +337,12 @@ the directory related options below.
             help=_('Set the series of the added book(s)'))
     parser.add_option('-S', '--series-index', default=1.0, type=float,
             help=_('Set the series number of the added book(s)'))
-
+    parser.add_option('-c', '--cover', default=None,
+            help=_('Path to the cover to use for the added book'))
 
     return parser
 
-def do_add_empty(db, title, authors, isbn, tags, series, series_index):
+def do_add_empty(db, title, authors, isbn, tags, series, series_index, cover):
     from calibre.ebooks.metadata import MetaInformation
     mi = MetaInformation(None)
     if title is not None:
@@ -343,6 +355,8 @@ def do_add_empty(db, title, authors, isbn, tags, series, series_index):
         mi.tags = tags
     if series:
         mi.series, mi.series_index = series, series_index
+    if cover:
+        mi.cover = cover
     db.import_book(mi, [])
     write_dirtied(db)
     send_message()
@@ -355,7 +369,7 @@ def command_add(args, dbpath):
     tags = [x.strip() for x in opts.tags.split(',')] if opts.tags else []
     if opts.empty:
         do_add_empty(get_db(dbpath, opts), opts.title, aut, opts.isbn, tags,
-                opts.series, opts.series_index)
+                opts.series, opts.series_index, opts.cover)
         return 0
     if len(args) < 2:
         parser.print_help()
@@ -364,7 +378,7 @@ def command_add(args, dbpath):
         return 1
     do_add(get_db(dbpath, opts), args[1:], opts.one_book_per_directory,
             opts.recurse, opts.duplicates, opts.title, aut, opts.isbn,
-            tags, opts.series, opts.series_index)
+            tags, opts.series, opts.series_index, opts.cover)
     return 0
 
 def do_remove(db, ids):
@@ -692,7 +706,22 @@ datatype is one of: {0}
             help=_('A dictionary of options to customize how '
                 'the data in this column will be interpreted. This is a JSON '
                 ' string. For enumeration columns, use '
-                '--display=\'{"enum_values":["val1", "val2"]}\''))
+                '--display="{\\"enum_values\\":[\\"val1\\", \\"val2\\"]}"'
+                '\n'
+                'There are many options that can go into the display variable.'
+                'The options by column type are:\n'
+                'composite: composite_template, composite_sort, make_category,'
+                'contains_html, use_decorations\n'
+                'datetime: date_format\n'
+                'enumeration: enum_values, enum_colors, use_decorations\n'
+                'int, float: number_format\n'
+                'text: is_names, use_decorations\n'
+                '\n'
+                'The best way to find legal combinations is to create a custom'
+                'column of the appropriate type in the GUI then look at the'
+                'backup OPF for a book (ensure that a new OPF has been created'
+                'since the column was added). You will see the JSON for the'
+                '"display" for the new column in the OPF.'))
     return parser
 
 
@@ -1264,8 +1293,7 @@ def command_list_categories(args, dbpath):
     fields = ['category', 'tag_name', 'count', 'rating']
 
     def do_list():
-        from calibre.constants import terminal_controller as tc
-        terminal_controller = tc()
+        from calibre.utils.terminal import geometry, ColoredStream
 
         separator = ' '
         widths = list(map(lambda x : 0, fields))
@@ -1273,7 +1301,7 @@ def command_list_categories(args, dbpath):
             for j, field in enumerate(fields):
                 widths[j] = max(widths[j], max(len(field), len(unicode(i[field]))))
 
-        screen_width = terminal_controller.COLS if opts.width < 0 else opts.width
+        screen_width = geometry()[0]
         if not screen_width:
             screen_width = 80
         field_width = screen_width//len(fields)
@@ -1292,7 +1320,8 @@ def command_list_categories(args, dbpath):
         widths = list(base_widths)
         titles = map(lambda x, y: '%-*s%s'%(x-len(separator), y, separator),
                 widths, fields)
-        print terminal_controller.GREEN + ''.join(titles)+terminal_controller.NORMAL
+        with ColoredStream(sys.stdout, fg='green'):
+            print ''.join(titles)
 
         wrappers = map(lambda x: TextWrapper(x-1), widths)
         o = cStringIO.StringIO()
