@@ -497,6 +497,13 @@ class FieldMetadata(dict):
     def is_custom_field(self, key):
         return key.startswith(self.custom_field_prefix)
 
+    def is_ignorable_field(self, key):
+        'Custom fields and user categories are ignorable'
+        return self.is_custom_field(key) or key.startswith('@')
+
+    def ignorable_field_keys(self):
+        return [k for k in self._tb_cats.iterkeys() if self.is_ignorable_field(k)]
+
     def is_series_index(self, key):
         m = self[key]
         return (m['datatype'] == 'float' and key.endswith('_index') and
