@@ -11,11 +11,11 @@ from collections import OrderedDict
 
 import cherrypy
 
-from calibre.constants import filesystem_encoding
-from calibre import isbytestring, force_unicode, fit_image, \
-        prepare_string_for_xml
+from calibre.constants import filesystem_encoding, config_dir
+from calibre import (isbytestring, force_unicode, fit_image,
+        prepare_string_for_xml, sanitize_file_name2)
 from calibre.utils.filenames import ascii_filename
-from calibre.utils.config import prefs
+from calibre.utils.config import prefs, JSONConfig
 from calibre.utils.icu import sort_key
 from calibre.utils.magick import Image
 from calibre.library.comments import comments_to_html
@@ -239,9 +239,13 @@ class BrowseServer(object):
                 self.browse_details)
         connect('browse_book', base_href+'/book/{id}',
                 self.browse_book)
+        connect('browse_random', base_href+'/random',
+                self.browse_random)
         connect('browse_category_icon', base_href+'/icon/{name}',
                 self.browse_icon)
 
+        self.icon_map = JSONConfig('gui').get('tags_browser_category_icons', {})
+
     # Templates {{{
     def browse_template(self, sort, category=True, initial_search=''):
 
@@ -265,7 +269,7 @@ class BrowseServer(object):
             for x in fm.sortable_field_keys():
                 if x in ('ondevice', 'formats', 'sort'):
                     continue
-                if fm[x]['is_custom'] and x not in displayed_custom_fields:
+                if fm.is_ignorable_field(x) and x not in displayed_custom_fields:
                     continue
                 if x == 'comments' or fm[x]['datatype'] == 'comments':
                     continue
@@ -321,10 +325,18 @@ class BrowseServer(object):
         if not hasattr(self, '__browse_icon_cache__'):
             self.__browse_icon_cache__ = {}
         if name not in self.__browse_icon_cache__:
-            try:
-                data = I(name, data=True)
-            except:
-                raise cherrypy.HTTPError(404, 'no icon named: %r'%name)
+            if name.startswith('_'):
+                name = sanitize_file_name2(name[1:])
+                try:
+                    with open(os.path.join(config_dir, 'tb_icons', name), 'rb') as f:
+                        data = f.read()
+                except:
+                    raise cherrypy.HTTPError(404, 'no icon named: %r'%name)
+            else:
+                try:
+                    data = I(name, data=True)
+                except:
+                    raise cherrypy.HTTPError(404, 'no icon named: %r'%name)
             img = Image()
             img.load(data)
             width, height = img.size
@@ -341,6 +353,7 @@ class BrowseServer(object):
         cats = [
                 (_('Newest'), 'newest', 'forward.png'),
                 (_('All books'), 'allbooks', 'book.png'),
+                (_('Random book'), 'randombook', 'random.png'),
                 ]
 
         def getter(x):
@@ -356,10 +369,15 @@ class BrowseServer(object):
             meta = category_meta.get(category, None)
             if meta is None:
                 continue
-            if meta['is_custom'] and category not in displayed_custom_fields:
+            if self.db.field_metadata.is_ignorable_field(category) and \
+                        category not in displayed_custom_fields:
                 continue
             # get the icon files
-            if category in category_icon_map:
+            main_cat = (category.partition('.')[0]) if hasattr(category,
+                                                    'partition') else category
+            if main_cat in self.icon_map:
+                icon = '_'+quote(self.icon_map[main_cat])
+            elif category in category_icon_map:
                 icon = category_icon_map[category]
             elif meta['is_custom']:
                 icon = category_icon_map['custom:']
@@ -429,7 +447,11 @@ class BrowseServer(object):
             cat_len = len(category)
             if not (len(ucat) > cat_len and ucat.startswith(category+'.')):
                 continue
-            icon = category_icon_map['user:']
+
+            if ucat in self.icon_map:
+                icon = '_'+quote(self.icon_map[ucat])
+            else:
+                icon = category_icon_map['user:']
             # we have a subcategory. Find any further dots (further subcats)
             cat_len += 1
             cat = ucat[cat_len:]
@@ -583,6 +605,9 @@ class BrowseServer(object):
         elif category == 'allbooks':
             raise cherrypy.InternalRedirect(prefix +
                     '/browse/matches/allbooks/dummy')
+        elif category == 'randombook':
+            raise cherrypy.InternalRedirect(prefix +
+                    '/browse/random')
         else:
             ans = self.browse_category(category, category_sort)
 
@@ -812,7 +837,8 @@ class BrowseServer(object):
             displayed_custom_fields = custom_fields_to_display(self.db)
             for field, m in list(mi.get_all_standard_metadata(False).items()) + \
                     list(mi.get_all_user_metadata(False).items()):
-                if m['is_custom'] and field not in displayed_custom_fields:
+                if self.db.field_metadata.is_ignorable_field(field) and \
+                                field not in displayed_custom_fields:
                     continue
                 if m['datatype'] == 'comments' or field == 'comments' or (
                         m['datatype'] == 'composite' and \
@@ -869,6 +895,14 @@ class BrowseServer(object):
 
         return json.dumps(ans, ensure_ascii=False)
 
+    @Endpoint()
+    def browse_random(self, *args, **kwargs):
+        import random
+        book_id = random.choice(self.db.search_getting_ids(
+            '', self.search_restriction))
+        ans = self.browse_render_details(book_id)
+        return self.browse_template('').format(
+                title='', script='book();', main=ans)
 
     @Endpoint()
     def browse_book(self, id=None, category_sort=None):
