@@ -89,7 +89,7 @@ magick_PixelWand_color_setter(magick_PixelWand *self, PyObject *val, void *closu
 // PixelWand.destroy {{{
 
 static PyObject *
-magick_PixelWand_destroy(magick_PixelWand *self, PyObject *args, PyObject *kwargs) {
+magick_PixelWand_destroy(magick_PixelWand *self, PyObject *args) {
     NULL_CHECK(NULL)
     self->wand = DestroyPixelWand(self->wand);
     Py_RETURN_NONE;
@@ -197,7 +197,7 @@ magick_DrawingWand_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 // DrawingWand.destroy {{{
 
 static PyObject *
-magick_DrawingWand_destroy(magick_DrawingWand *self, PyObject *args, PyObject *kwargs) {
+magick_DrawingWand_destroy(magick_DrawingWand *self, PyObject *args) {
     NULL_CHECK(NULL)
     self->wand = DestroyDrawingWand(self->wand);
     Py_RETURN_NONE;
@@ -493,8 +493,9 @@ typedef struct {
 } magick_Image;
 
 // Method declarations {{{
-static PyObject* magick_Image_compose(magick_Image *self, PyObject *args, PyObject *kwargs);
-static PyObject* magick_Image_copy(magick_Image *self, PyObject *args, PyObject *kwargs);
+static PyObject* magick_Image_compose(magick_Image *self, PyObject *args);
+static PyObject* magick_Image_copy(magick_Image *self, PyObject *args);
+static PyObject* magick_Image_texture(magick_Image *self, PyObject *args);
 // }}}
 
 static void
@@ -526,7 +527,7 @@ magick_Image_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 
 // Image.load {{{
 static PyObject *
-magick_Image_load(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_load(magick_Image *self, PyObject *args) {
     const char *data;
 	Py_ssize_t dlen;
     MagickBooleanType res;
@@ -546,7 +547,7 @@ magick_Image_load(magick_Image *self, PyObject *args, PyObject *kwargs) {
 
 // Image.identify {{{
 static PyObject *
-magick_Image_identify(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_identify(magick_Image *self, PyObject *args) {
     const char *data;
 	Py_ssize_t dlen;
     MagickBooleanType res;
@@ -566,7 +567,7 @@ magick_Image_identify(magick_Image *self, PyObject *args, PyObject *kwargs) {
 
 // Image.open {{{
 static PyObject *
-magick_Image_read(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_read(magick_Image *self, PyObject *args) {
     const char *data;
     MagickBooleanType res;
     
@@ -585,7 +586,7 @@ magick_Image_read(magick_Image *self, PyObject *args, PyObject *kwargs) {
 
 // Image.create_canvas {{{
 static PyObject *
-magick_Image_create_canvas(magick_Image *self, PyObject *args, PyObject *kwargs)
+magick_Image_create_canvas(magick_Image *self, PyObject *args)
 {
     Py_ssize_t width, height;
     char *bgcolor;
@@ -610,7 +611,7 @@ magick_Image_create_canvas(magick_Image *self, PyObject *args, PyObject *kwargs)
 // Image.font_metrics {{{
 
 static PyObject *
-magick_Image_font_metrics(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_font_metrics(magick_Image *self, PyObject *args) {
     char *text;
     PyObject *dw_, *ans, *m;
     Py_ssize_t i;
@@ -640,7 +641,7 @@ magick_Image_font_metrics(magick_Image *self, PyObject *args, PyObject *kwargs)
 // Image.annotate {{{
 
 static PyObject *
-magick_Image_annotate(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_annotate(magick_Image *self, PyObject *args) {
     char *text;
     PyObject *dw_;
     DrawingWand *dw;
@@ -661,7 +662,7 @@ magick_Image_annotate(magick_Image *self, PyObject *args, PyObject *kwargs) {
 // Image.export {{{
 
 static PyObject *
-magick_Image_export(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_export(magick_Image *self, PyObject *args) {
     char *fmt;
     unsigned char *data;
     PyObject *ans;
@@ -789,7 +790,7 @@ magick_Image_format_setter(magick_Image *self, PyObject *val, void *closure) {
 // Image.distort {{{
 
 static PyObject *
-magick_Image_distort(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_distort(magick_Image *self, PyObject *args) {
     int method;
     Py_ssize_t i, number;
     PyObject *bestfit, *argv, *t;
@@ -825,7 +826,7 @@ magick_Image_distort(magick_Image *self, PyObject *args, PyObject *kwargs) {
 // Image.trim {{{
 
 static PyObject *
-magick_Image_trim(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_trim(magick_Image *self, PyObject *args) {
     double fuzz;
     
     NULL_CHECK(NULL)
@@ -841,7 +842,7 @@ magick_Image_trim(magick_Image *self, PyObject *args, PyObject *kwargs) {
 // Image.thumbnail {{{
 
 static PyObject *
-magick_Image_thumbnail(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_thumbnail(magick_Image *self, PyObject *args) {
     Py_ssize_t width, height;
     
     NULL_CHECK(NULL)
@@ -857,7 +858,7 @@ magick_Image_thumbnail(magick_Image *self, PyObject *args, PyObject *kwargs) {
 // Image.crop {{{
 
 static PyObject *
-magick_Image_crop(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_crop(magick_Image *self, PyObject *args) {
     Py_ssize_t width, height, x, y;
     
     NULL_CHECK(NULL)
@@ -873,7 +874,7 @@ magick_Image_crop(magick_Image *self, PyObject *args, PyObject *kwargs) {
 // Image.set_border_color {{{
 
 static PyObject *
-magick_Image_set_border_color(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_set_border_color(magick_Image *self, PyObject *args) {
     PyObject *obj;
     magick_PixelWand *pw;
     
@@ -892,7 +893,7 @@ magick_Image_set_border_color(magick_Image *self, PyObject *args, PyObject *kwar
 // Image.rotate {{{
 
 static PyObject *
-magick_Image_rotate(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_rotate(magick_Image *self, PyObject *args) {
     PyObject *obj;
     magick_PixelWand *pw;
     double degrees;
@@ -909,10 +910,27 @@ magick_Image_rotate(magick_Image *self, PyObject *args, PyObject *kwargs) {
 }
 // }}}
 
+// Image.rotate {{{
+
+static PyObject *
+magick_Image_flip(magick_Image *self, PyObject *args) {
+    PyObject *obj = NULL;
+    MagickBooleanType ret = 0;
+    
+    NULL_CHECK(NULL)
+
+    if (!PyArg_ParseTuple(args, "|O", &obj)) return NULL;
+    ret = (obj != NULL && PyObject_IsTrue(obj)) ? MagickFlopImage(self->wand) : MagickFlipImage(self->wand);
+    if (!ret) { PyErr_SetString(PyExc_ValueError, "Failed to flip image"); return NULL; }
+
+    Py_RETURN_NONE;
+}
+// }}}
+
 // Image.set_page {{{
 
 static PyObject *
-magick_Image_set_page(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_set_page(magick_Image *self, PyObject *args) {
     Py_ssize_t width, height, x, y;
     
     NULL_CHECK(NULL)
@@ -928,7 +946,7 @@ magick_Image_set_page(magick_Image *self, PyObject *args, PyObject *kwargs) {
 // Image.set_compression_quality {{{
 
 static PyObject *
-magick_Image_set_compression_quality(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_set_compression_quality(magick_Image *self, PyObject *args) {
     Py_ssize_t quality;
     
     NULL_CHECK(NULL)
@@ -944,7 +962,7 @@ magick_Image_set_compression_quality(magick_Image *self, PyObject *args, PyObjec
 // Image.has_transparent_pixels {{{
 
 static PyObject *
-magick_Image_has_transparent_pixels(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_has_transparent_pixels(magick_Image *self, PyObject *args) {
     PixelIterator *pi = NULL;
     PixelWand **pixels = NULL;
     int found = 0;
@@ -975,7 +993,7 @@ magick_Image_has_transparent_pixels(magick_Image *self, PyObject *args, PyObject
 // Image.normalize {{{
 
 static PyObject *
-magick_Image_normalize(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_normalize(magick_Image *self, PyObject *args) {
     NULL_CHECK(NULL)
 
     if (!MagickNormalizeImage(self->wand)) return magick_set_exception(self->wand);
@@ -987,7 +1005,7 @@ magick_Image_normalize(magick_Image *self, PyObject *args, PyObject *kwargs) {
 // Image.add_border {{{
 
 static PyObject *
-magick_Image_add_border(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_add_border(magick_Image *self, PyObject *args) {
     Py_ssize_t dx, dy;
     PyObject *obj;
     magick_PixelWand *pw;
@@ -1007,7 +1025,7 @@ magick_Image_add_border(magick_Image *self, PyObject *args, PyObject *kwargs) {
 // Image.sharpen {{{
 
 static PyObject *
-magick_Image_sharpen(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_sharpen(magick_Image *self, PyObject *args) {
     double radius, sigma;
    
     NULL_CHECK(NULL)
@@ -1023,7 +1041,7 @@ magick_Image_sharpen(magick_Image *self, PyObject *args, PyObject *kwargs) {
 // Image.quantize {{{
 
 static PyObject *
-magick_Image_quantize(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_quantize(magick_Image *self, PyObject *args) {
     Py_ssize_t number_colors, treedepth;
     int colorspace;
     PyObject *dither, *measure_error;
@@ -1042,7 +1060,7 @@ magick_Image_quantize(magick_Image *self, PyObject *args, PyObject *kwargs) {
 // Image.despeckle {{{
 
 static PyObject *
-magick_Image_despeckle(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_despeckle(magick_Image *self, PyObject *args) {
     NULL_CHECK(NULL)
 
     if (!MagickDespeckleImage(self->wand)) return magick_set_exception(self->wand);
@@ -1086,16 +1104,67 @@ magick_Image_type_setter(magick_Image *self, PyObject *val, void *closure) {
 
 // }}}
 
+// Image.depth {{{
+static PyObject *
+magick_Image_depth_getter(magick_Image *self, void *closure) {
+   NULL_CHECK(NULL)
+
+    return Py_BuildValue("n", MagickGetImageDepth(self->wand));
+}
+
+static int
+magick_Image_depth_setter(magick_Image *self, PyObject *val, void *closure) {
+    size_t depth;
+
+    NULL_CHECK(-1)
+
+    if (val == NULL) {
+        PyErr_SetString(PyExc_TypeError, "Cannot delete image depth");
+        return -1;
+    }
+
+    if (!PyInt_Check(val)) {
+        PyErr_SetString(PyExc_TypeError, "Depth must be an integer");
+        return -1;
+    }
+
+    depth = (size_t)PyInt_AsSsize_t(val);
+    if (!MagickSetImageDepth(self->wand, depth)) {
+        PyErr_Format(PyExc_ValueError, "Could not set image depth to %lu", depth);
+        return -1;
+    }
+
+    return 0;
+}
+
+// }}}
+
 // Image.destroy {{{
 
 static PyObject *
-magick_Image_destroy(magick_Image *self, PyObject *args, PyObject *kwargs) {
+magick_Image_destroy(magick_Image *self, PyObject *args) {
     NULL_CHECK(NULL)
     self->wand = DestroyMagickWand(self->wand);
     Py_RETURN_NONE;
 }
 // }}}
 
+// Image.set_opacity {{{
+
+static PyObject *
+magick_Image_set_opacity(magick_Image *self, PyObject *args) {
+    double opacity;
+    NULL_CHECK(NULL)
+
+   
+    if (!PyArg_ParseTuple(args, "d", &opacity)) return NULL;
+
+    if (!MagickSetImageOpacity(self->wand, opacity)) return magick_set_exception(self->wand);
+
+    Py_RETURN_NONE;
+}
+// }}}
+
 // Image attr list {{{
 static PyMethodDef magick_Image_methods[] = {
     {"destroy", (PyCFunction)magick_Image_destroy, METH_VARARGS,
@@ -1127,6 +1196,14 @@ static PyMethodDef magick_Image_methods[] = {
      "compose(img, left, top, op) \n\n Compose img using operation op at (left, top)"
     },
 
+    {"texture", (PyCFunction)magick_Image_texture, METH_VARARGS,
+     "texture(img)) \n\n Repeatedly tile img across and down the canvas."
+    },
+
+    {"set_opacity", (PyCFunction)magick_Image_set_opacity, METH_VARARGS,
+     "set_opacity(opacity)) \n\n Set the opacity of this image (between 0.0 - transparent and 1.0 - opaque)"
+    },
+
     {"copy", (PyCFunction)magick_Image_copy, METH_VARARGS,
      "copy(img) \n\n Copy img to self."
     },
@@ -1174,6 +1251,10 @@ static PyMethodDef magick_Image_methods[] = {
     {"rotate", (PyCFunction)magick_Image_rotate, METH_VARARGS,
      "rotate(background_pixel_wand, degrees) \n\n Rotate image by specified degrees."
     },
+    {"flip", (PyCFunction)magick_Image_flip, METH_VARARGS,
+     "flip(horizontal=False) \n\n Flip image about a vertical axis. If horizontal is True, flip about horizontal axis instead."
+    },
+
 
     {"normalize", (PyCFunction)magick_Image_normalize, METH_VARARGS,
      "normalize() \n\n enhances the contrast of a color image by adjusting the pixels color to span the entire range of colors available."
@@ -1192,7 +1273,7 @@ static PyMethodDef magick_Image_methods[] = {
     },
 
     {"quantize", (PyCFunction)magick_Image_quantize, METH_VARARGS,
-     "quantize(number_colors, colorspace, treedepth, dither, measure_error) \n\n nalyzes the colors within a reference image and chooses a fixed number of colors to represent the image. The goal of the algorithm is to minimize the color difference between the input and output image while minimizing the processing time." 
+     "quantize(number_colors, colorspace, treedepth, dither, measure_error) \n\n analyzes the colors within a reference image and chooses a fixed number of colors to represent the image. The goal of the algorithm is to minimize the color difference between the input and output image while minimizing the processing time." 
     },
 
     {NULL}  /* Sentinel */
@@ -1214,6 +1295,12 @@ static PyGetSetDef  magick_Image_getsetters[] = {
      (char *)"the image type: UndefinedType, BilevelType, GrayscaleType, GrayscaleMatteType, PaletteType, PaletteMatteType, TrueColorType, TrueColorMatteType, ColorSeparationType, ColorSeparationMatteType, or OptimizeType.",
      NULL},
 
+    {(char *)"depth",
+     (getter)magick_Image_depth_getter, (setter)magick_Image_depth_setter,
+     (char *)"the image depth.",
+     NULL},
+
+
     {NULL}  /* Sentinel */
 };
 
@@ -1264,7 +1351,7 @@ static PyTypeObject magick_ImageType = { // {{{
 
 // Image.compose {{{
 static PyObject *
-magick_Image_compose(magick_Image *self, PyObject *args, PyObject *kwargs)
+magick_Image_compose(magick_Image *self, PyObject *args)
 {
     PyObject *img, *op_;
     ssize_t left, top;
@@ -1295,7 +1382,7 @@ magick_Image_compose(magick_Image *self, PyObject *args, PyObject *kwargs)
 
 // Image.clone {{{
 static PyObject *
-magick_Image_copy(magick_Image *self, PyObject *args, PyObject *kwargs)
+magick_Image_copy(magick_Image *self, PyObject *args)
 {
     PyObject *img;
     magick_Image *src;
@@ -1313,6 +1400,23 @@ magick_Image_copy(magick_Image *self, PyObject *args, PyObject *kwargs)
 }
 // }}}
 
+// Image.texture {{{
+static PyObject *
+magick_Image_texture(magick_Image *self, PyObject *args) {
+    PyObject *img;
+    magick_Image *texture;
+
+    NULL_CHECK(NULL)
+
+    if (!PyArg_ParseTuple(args, "O!", &magick_ImageType, &img)) return NULL;
+    texture = (magick_Image*)img;
+    if (!IsMagickWand(texture->wand)) {PyErr_SetString(PyExc_TypeError, "Not a valid ImageMagick wand"); return NULL;}
+
+    self->wand = MagickTextureImage(self->wand, texture->wand);
+
+    Py_RETURN_NONE;
+}
+
 // }}}
 
 // Module functions {{{
